# Batching

::: torchlinops.linops.Batch
    options:
        inherited_members: false
        members:
            - __init__
            - normal

::: torchlinops.linops.MPBatch
    options:
        inherited_members: false
        members:
            - __init__
